@@ -10,7 +10,12 @@ from helpers import is_sequence, convert_unicode
 
 from Products.PageTemplates.Expressions import SecureModuleImporter
 
-from zope.i18nmessageid import MessageIDFactory
+try:
+     #Zope since 2.10
+     from zope.i18nmessageid import MessageFactory
+except ImportError:
+     #BBB Zope 2.9 and earlier
+     from zope.i18nmessageid import MessageIDFactory as MessageFactory
 
 class Field:
     """Base class of all fields.
@@ -133,7 +138,7 @@ class Field:
         if id in ['title', 'description']:
             i18n_domain = self.get_i18n_domain()
             if i18n_domain:
-                return MessageIDFactory(i18n_domain)(value)
+                return MessageFactory(i18n_domain)(value)
         return value
 
     # this also works if field is not in form for testing
@@ -213,7 +218,7 @@ class Field:
         else:
             if want_message_id:
                 # we do want a message id, so construct one from form domain
-                result = MessageIDFactory(self.get_i18n_domain())(result)
+                result = MessageFactory(self.get_i18n_domain())(result)
             return result
     
     security.declarePrivate('_render_helper')
@@ -408,21 +413,21 @@ class ZMIField(
                 getattr(self, method_name)(values[key])
 
 
-    security.declareProtected('Change Formulator Forms', 'manage_beforeDelete')
-    def manage_beforeDelete(self, item, container):
-        """Remove name from list if object is deleted.
-        """
-        # update group info in form
-        if hasattr(item.aq_explicit, 'is_field'):
-            container.field_removed(item.id)
+##     security.declareProtected('Change Formulator Forms', 'manage_beforeDelete')
+##     def manage_beforeDelete(self, item, container):
+##         """Remove name from list if object is deleted.
+##         """
+##         # update group info in form
+##         if hasattr(item.aq_explicit, 'is_field'):
+##             container.field_removed(item.id)
 
-    security.declareProtected('Change Formulator Forms', 'manage_afterAdd')
-    def manage_afterAdd(self, item, container):
-        """What happens when we add a field.
-        """
-        # update group info in form
-        if hasattr(item.aq_explicit, 'is_field'):
-            container.field_added(item.id)
+##     security.declareProtected('Change Formulator Forms', 'manage_afterAdd')
+##     def manage_afterAdd(self, item, container):
+##         """What happens when we add a field.
+##         """
+##         # update group info in form
+##         if hasattr(item.aq_explicit, 'is_field'):
+##             container.field_added(item.id)
 
     # methods screen
     security.declareProtected('View management screens',
@@ -568,4 +573,12 @@ class ZClassField(Field):
     pass
 
 
+def field_added(object, event):
+     # update group info in form
+     if hasattr(object.aq_explicit, 'is_field'):
+          event.newParent.field_added(object.id)
 
+def field_removed(object, event):
+     # update group info in form
+     if hasattr(object.aq_explicit, 'is_field'):
+          event.oldParent.field_removed(object.id)
