@@ -8,6 +8,7 @@ from urlparse import urljoin
 from Errors import ValidationError
 from helpers import is_sequence
 from Products.Formulator.i18n import translate as _
+from types import UnicodeType
 
 try:
     from DateTime.DateTime import DateError, TimeError
@@ -152,7 +153,7 @@ class StringValidator(StringBaseValidator):
 
     def validate(self, field, key, REQUEST):
         value = StringBaseValidator.validate(self, field, key, REQUEST)
-        if field.get_value('unicode'):
+        if field.get_value('unicode') and not isinstance(value,UnicodeType):
             # use acquisition to get encoding of form
             value = unicode(value, field.get_form_encoding())
 
@@ -369,7 +370,7 @@ class LinesValidator(StringBaseValidator):
         # we need to add this check again
         if value == "" and not field.get_value('required'):
             return []
-        if field.get_value('unicode'):
+        if field.get_value('unicode') and not isinstance(value,UnicodeType):
             value = unicode(value, field.get_form_encoding())
         # check whether the entire input is too long
         max_length = field.get_value('max_length') or 0
@@ -455,7 +456,7 @@ class SelectionValidator(StringBaseValidator):
             # will remain integers.
             # XXX it is impossible with the UI currently to fill in unicode
             # items, but it's possible to do it with the TALES tab
-            if field.get_value('unicode') and type(item_value) == type(u''):
+            if field.get_value('unicode') and isinstance(value,UnicodeType):
                 str_value = item_value.encode(field.get_form_encoding())
             else:
                 str_value = str(item_value)
@@ -506,7 +507,7 @@ class MultiSelectionValidator(Validator):
                 return values
         # convert everything to unicode if necessary
         if field.get_value('unicode'):
-            values = [unicode(value, field.get_form_encoding())
+            values = [not isinstance(value,UnicodeType) and unicode(value, field.get_form_encoding()) or value
                       for value in values]
 
         # create a dictionary of possible values
